OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migraatio on kesken. Odota kunnes migraatio valmistuu",
    "Migration started …" : "Migraatio käynnistyi…",
    "Saved" : "Tallennettu",
    "Not saved" : "Ei tallennettu",
    "Sending…" : "Lähetetään…",
    "Email sent" : "Sähköposti lähetetty",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Tapahtu virhe. Lähetä ASCII-koodattu PEM-varmenne.",
    "Valid until {date}" : "Kelvollinen {date} asti",
    "Delete" : "Poista",
    "Local" : "Paikallinen",
    "Private" : "Yksityinen",
    "Only visible to local users" : "Näkyvillä vain paikallisille käyttäjille",
    "Only visible to you" : "Näkyvillä vain sinulle",
    "Contacts" : "Yhteystiedot",
    "Visible to local users and to trusted servers" : "Näkyvillä vain paikallisille käyttäjille ja luotetuille palvelimille",
    "Public" : "Julkinen",
    "Will be synced to a global and public address book" : "Synkronoidaan maailmanlaajuiseen ja julkiseen osoitekirjaan",
    "Verify" : "Vahvista",
    "Verifying …" : "Vahvistetaan…",
    "Unable to change password" : "Salasanan vaihto ei onnistunut",
    "Very weak password" : "Erittäin heikko salasana",
    "Weak password" : "Heikko salasana",
    "So-so password" : "Kohtalainen salasana",
    "Good password" : "Hyvä salasana",
    "Strong password" : "Vahva salasana",
    "An error occurred while changing your language. Please reload the page and try again." : "Kieltä vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Maa-asetustoa vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
    "Select a profile picture" : "Valitse profiilikuva",
    "Week starts on {fdow}" : "Viikon ensimmäinen päivä on {fdow}",
    "Groups" : "Ryhmät",
    "Group list is empty" : "Ryhmälista on tyhjä",
    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
    "{actor} added you to group {group}" : "{actor} lisäsi sinut ryhmään {group}",
    "You added {user} to group {group}" : "Lisäsit käyttäjän {user} ryhmään {group}",
    "{actor} added {user} to group {group}" : "{actor} lisäsi käyttäjän {user} ryhmään {group}",
    "An administrator added you to group {group}" : "Ylläpitäjä lisäsi sinut ryhmään {group}",
    "An administrator added {user} to group {group}" : "Ylläpitäjä lisäsi käyttäjän {user} ryhmään {group}",
    "{actor} removed you from group {group}" : "{actor} poisti sinut ryhmästä {group}",
    "You removed {user} from group {group}" : "Poistit käyttäjän {user} ryhmästä {group}",
    "{actor} removed {user} from group {group}" : "{actor} poisti käyttäjän {user} ryhmästä {group}",
    "An administrator removed you from group {group}" : "Ylläpitäjä poisti sinut ryhmästä {group}",
    "An administrator removed {user} from group {group}" : "Ylläpitäjä poisti käyttäjän {user} ryhmästä {group}",
    "Your <strong>group memberships</strong> were modified" : "Sinun <strong>ryhmäjäsenyyksiä</strong> muokattiin",
    "{actor} changed your password" : "{actor} muutti salasanasi",
    "You changed your password" : "Muutit salasanasi",
    "Your password was reset by an administrator" : "Ylläpitäjä nollasi salasanasi",
    "{actor} changed your email address" : "{actor} muutti sähköpostiosoitteesi",
    "You changed your email address" : "Muutit sähköpostiosoitteesi",
    "Your email address was changed by an administrator" : "Ylläpitäjä muutti sähköpostiosoitteesi",
    "You created app password \"{token}\"" : "Loit sovellussalasanan \"{token}\"",
    "You deleted app password \"{token}\"" : "Poistit sovellussalasanan \"{token}\"",
    "Security" : "Turvallisuus",
    "You successfully logged in using two-factor authentication (%1$s)" : "Kirjauduit onnistuneesti sisään kaksivaiheista tunnistautumista käyttäen (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Kirjautumisyritys kaksivaiheista tunnistautumista käyttäen epäonnistui (%1$s)",
    "Remote wipe was started on %1$s" : "Etätyhjennys aloitettiin %1$s",
    "Remote wipe has finished on %1$s" : "Etätyhjennys valmistui %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Salasanaasi</strong> tai <strong>sähköpostiosoitettasi</strong> muokattiin",
    "Couldn't remove app." : "Sovelluksen poistaminen epäonnistui.",
    "Couldn't update app." : "Sovelluksen päivitys epäonnistui.",
    "Wrong password" : "Väärä salasana",
    "No user supplied" : "Käyttäjää ei määritetty",
    "Authentication error" : "Tunnistautumisvirhe",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Anna ylläpitäjän palautussalasana; muuten kaikki käyttäjien data menetetään.",
    "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Taustaosa ei tue salasanan vaihtamista, mutta käyttäjän salausavain päivitettiin.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "Sovellusten asennus tai päivitys sovelluskaupasta tai federoidusta pilvijaosta",
    "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
    "Invalid SMTP password." : "Virheellinen SMTP-salasana.",
    "Email setting test" : "Sähköpostiasetusten testaus",
    "Well done, %s!" : "Hyvin tehty, %s!",
    "If you received this email, the email configuration seems to be correct." : "Jos vastaanotit tämän viestin, sähköpostimääritykset vaikuttavat olevan kunnossa.",
    "Email could not be sent. Check your mail server log" : "Sähköpostia ei voitu lähettää. Tarkista sähköpostipalvelimen lokitiedosto",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Sähköpostia lähettäessä tapahtui virhe. Tarkista asetukset. (Virhe: %s)",
    "You need to set your user email before being able to send test emails." : "Aseta sähköpostiosoite, jotta voit testata sähköpostin toimivuutta.",
    "Invalid mail address" : "Virheellinen sähköpostiosoite",
    "Settings saved" : "Asetukset tallennettu",
    "Unable to change full name" : "Koko nimen muuttaminen epäonnistui",
    "Unable to change email address" : "Sähköpostiosoitteen vaihtaminen ei onnistunut",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Jotta Twitter-tilisi on mahdollista vahvistaa, twiittaa seuraava viesti (varmista että lähetät viestin sellaisenaan ilman rivivaihtoja):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Jotta verkkosivustosi on mahdollista vahvistaa, aseta seuraava sisältö verkkosivustosi juureen '.well-known/CloudIdVerificationCode.txt' (varmista että koko teksti on yhdellä rivillä):",
    "Your password on %s was changed." : "Salasanasi osoitteessa %s on muutettu.",
    "Your password on %s was reset by an administrator." : "Ylläpitäjä muutti salasanasi osoitteessa %s.",
    "Password for %1$s changed on %2$s" : "Salasana käyttäjälle %1$s muutettu osoitteessa %2$s",
    "Password changed for %s" : "Salasana muutettu käyttäjälle %s",
    "If you did not request this, please contact an administrator." : "Jos et pyytänyt tätä, ota yhteyttä ylläpitäjään.",
    "Your email address on %s was changed." : "Sähköpostiosoitteesi osoitteessa %s on muutettu.",
    "Your email address on %s was changed by an administrator." : "Ylläpitäjä muutti sähköpostiosoitteesi osoitteessa %s.",
    "Email address for %1$s changed on %2$s" : "Sähköpostiosoite käyttäjälle %1$s muutettu osoitteessa %2$s",
    "Email address changed for %s" : "Sähköpostiosoite muutettu käyttäjälle %s",
    "The new email address is %s" : "Uusi sähköpostiosoite on %s",
    "Your %s account was created" : "%s-tilisi luotiin",
    "Welcome aboard" : "Tervetuloa mukaan",
    "Welcome aboard %s" : "Tervetuloa mukaan %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Tervetuloa %s-tilillesi. Voit lisätä, suojata ja jakaa tietojasi.",
    "Your username is: %s" : "Käyttäjätunnuksesi on: %s",
    "Set your password" : "Aseta salasanasi",
    "Go to %s" : "Siirry %s-palveluun",
    "Install Client" : "Asenna sovellus",
    "Create" : "Luo",
    "Change" : "Muuta",
    "Share" : "Jaa",
    "Unlimited" : "Rajoittamaton",
    "Verifying" : "Vahvistetaan",
    "Nextcloud settings" : "Nextcloud-asetukset",
    "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Kaksivaiheinen tunnistautuminen voidaan pakottaa kaikille\tkäyttäjille ja tietyille ryhmille. Mikäli heillä ei ole kaksivaiheista tunnistautumistapaa määriteltynä, he eivät pysty kirjautumaan järjestelmään.",
    "Enforce two-factor authentication" : "Pakota kaksivaiheinen tunnistautuminen",
    "Limit to groups" : "Rajoita ryhmiin",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Kaksivaiheisen tunnistautumisen pakottaminen on mahdollista kohdentaa vain tietyille ryhmille.",
    "Two-factor authentication is enforced for all\tmembers of the following groups." : "Kaksivaiheisen tunnistautuminen on pakotettu kaikille\tseuraavien ryhmien jäsenille.",
    "Enforced groups" : "Pakotetut ryhmät",
    "Two-factor authentication is not enforced for\tmembers of the following groups." : "Kaksivaiheinen tunnistautuminen ei ole pakotettu\tseuraavien ryhmien jäsenille.",
    "Save changes" : "Tallenna muutokset",
    "This app is supported via your current Nextcloud subscription." : "Tämä sovellus on tuettu nykyisen Nextcloud-tilauksesi kautta.",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Viralliset sovellukset ovat yhteisössä kehitettyjä. Ne tarjoavat keskeistä toiminnallisuutta ja ovat valmiita tuotantokäyttöön.",
    "Official" : "Virallinen",
    "Update to {version}" : "Päivitä versioon {version}",
    "Remove" : "Poista",
    "Disable" : "Poista käytöstä",
    "All" : "Kaikki",
    "Limit app usage to groups" : "Rajoita sovelluskäyttö ryhmiin",
    "No results" : "Ei tuloksia",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt minimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt maksimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tätä sovellusta ei voi asentaa, koska seuraavat riippuvuudet eivät täyty:",
    "View in store" : "Näytä kaupassa",
    "Visit website" : "Käy verkkosivustolla",
    "Report a bug" : "Ilmoita viasta",
    "User documentation" : "Käyttäjädokumentaatio",
    "Admin documentation" : "Ylläpitäjän ohjeistus",
    "Developer documentation" : "Kehittäjädokumentaatio",
    "Update to {update}" : "Päivitä versioon {update}",
    "Results from other categories" : "Tulokset muista luokista",
    "No apps found for your version" : "Sovelluksia ei löytynyt versiollesi",
    "Disable all" : "Poista kaikki käytöstä",
    "Enable all" : "Ota kaikki käyttöön",
    "Download and enable" : "Lataa ja ota käyttöön",
    "Enable" : "Käytä",
    "The app will be downloaded from the app store" : "Sovellus ladataan sovelluskaupasta",
    "Marked for remote wipe" : "Merkitty etätyhjennettäväksi",
    "Device settings" : "Laiteasetukset",
    "Allow filesystem access" : "Salli pääsy tiedostojärjestelmään",
    "Rename" : "Nimeä uudelleen",
    "Revoke" : "Peru oikeus",
    "Wipe device" : "Tyhjennä laite",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome Android-laitteelle",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Nextcloudin iOS-sovellus",
    "Nextcloud Android app" : "Nextcloudin Android-sovellus",
    "Nextcloud Talk for iOS" : "Nextcloud Talk iOS:ille",
    "Nextcloud Talk for Android" : "Nextcloud Talk Androidille",
    "Sync client - {os}" : "Synkronointisovellus - {os}",
    "This session" : "Tämä istunto",
    "Device" : "Laite",
    "Last activity" : "Viimeksi käytetty",
    "Devices & sessions" : "Laitteet ja istunnot",
    "Web, desktop and mobile clients currently logged in to your account." : "Verkko-, työpöytä- ja mobiililaitteet, jotka ovat parhaillaan kirjautuneet tilillesi.",
    "Do you really want to wipe your data from this device?" : "Haluatko varmasit tyhjentää tiedot tältä laitteelta?",
    "Confirm wipe" : "Vahvista tyhjentäminen",
    "Error while creating device token" : "Virhe laitepolettia luotaessa",
    "Error while updating device token name" : "Virhe laitepoletin nimeä päivittäessä",
    "Error while deleting the token" : "Virhe polettia poistaessa",
    "Error while wiping the device with the token" : "Virhe tyhjennettäessä laitetta polettia käyttäen",
    "App name" : "Sovelluksen nimi",
    "Create new app password" : "Luo uusi sovellussalasana",
    "Use the credentials below to configure your app or device." : "Käytä oheista tunnusta ja salasanaa konfiguroidessasi sovelluksen tai laitteen.",
    "For security reasons this password will only be shown once." : "Turvallisuussyistä tämä salasana näytetään vain kerran.",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Done" : "Valmis",
    "Show QR code for mobile apps" : "Näytä QR-koodi mobiilisovelluksia varten",
    "Copied!" : "Kopioitu!",
    "Copy" : "Kopioi",
    "You do not have permissions to see the details of this user" : "Käyttöoikeutesi eivät riitä tämän käyttäjän tietojen näkemiseen",
    "New password" : "Uusi salasana",
    "Add user in group" : "Lisää käyttäjä ryhmään",
    "Select user quota" : "Valitse käyttäjäkiintiö",
    "No language set" : "Kieltä ei ole asetettu",
    "Never" : "Ei koskaan",
    "Delete user" : "Poista käyttäjä",
    "Wipe all devices" : "Tyhjennä kaikki laitteet",
    "Disable user" : "Poista käyttäjä käytöstä",
    "Enable user" : "Ota käyttäjä käyttöön",
    "Resend welcome email" : "Lähetä uudelleen tervetuloviesti",
    "{size} used" : "{size} käytetty",
    "Welcome mail sent!" : "Tervetuloviesti lähetetty!",
    "Display name" : "Näyttönimi",
    "Email" : "Sähköpostiosoite",
    "Group admin for" : "Ryhmäylläpitäjä ryhmille",
    "Quota" : "Kiintiö",
    "Language" : "Kieli",
    "Storage location" : "Tallennustilan sijainti",
    "User backend" : "Käyttäjätaustaosa",
    "Last login" : "Viimeisin kirjautuminen",
    "Default language" : "Oletuskieli",
    "Add a new user" : "Lisää uusi käyttäjä",
    "No users in here" : "Täällä ei ole käyttäjiä",
    "Default quota" : "Oletuskiintiö",
    "Common languages" : "Yleiset kielet",
    "All languages" : "Kaikki kielet",
    "Your apps" : "Sovelluksesi",
    "Active apps" : "Aktiiviset sovellukset",
    "Disabled apps" : "Käytöstä poistetut sovellukset",
    "Updates" : "Päivitykset",
    "App bundles" : "Sovelluskokoelmat",
    "{license}-licensed" : "{license}-lisensoitu",
    "New user" : "Uusi käyttäjä",
    "Default quota:" : "Oletuskiintiö:",
    "Select default quota" : "Valitse oletuskiintiö",
    "Show Languages" : "Näytä kielet",
    "Show last login" : "Näytä viimeisin sisäänkirjautuminen",
    "Show user backend" : "Näytä käyttäjätaustaosa",
    "Show storage path" : "Näytä tallennustilan polku",
    "Remove group" : "Poista ryhmä",
    "Admins" : "Ylläpitäjät",
    "Disabled users" : "Käytöstä poistetut käyttäjät",
    "Everyone" : "Kaikki",
    "Add group" : "Lisää ryhmä",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Olet aikeissa poistaa ryhmän {group}. Käyttäjiä EI poisteta!",
    "Please confirm the group removal " : "Vahvista ryhmän poistaminen",
    "An error occured during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Sovellus on käytössä, mutta se tulee päivittää. Sinut ohjataan sovelluksen päivityssivulle viiden sekunnin kuluttua.",
    "App update" : "Sovelluspäivitys",
    "Error: This app can not be enabled because it makes the server unstable" : "Virhe: tätä sovellusta ei voi ottaa käyttöön, koska se tekee palvelimesta epävakaan",
    "SSL Root Certificates" : "SSL-juurivarmenteet",
    "Common Name" : "Yleinen nimi",
    "Valid until" : "Kelvollinen",
    "Issued By" : " Myöntänyt",
    "Valid until %s" : "Kelvollinen %s asti",
    "Import root certificate" : "Tuo juurivarmenne",
    "Administrator documentation" : "Ylläpidon dokumentaatio",
    "Documentation" : "Dokumentaatio",
    "Forum" : "Keskustelupalsta",
    "None" : "Ei mitään",
    "Login" : "Kirjaudu",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Sähköpostipalvelin",
    "Open documentation" : "Avaa dokumentaatio",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "On tärkeää määrittää sähköpostipalvelinasetukset, jotta voidaan lähettää muun muassa salasanan palautus- ja ilmoitussähköpostiviestejä.",
    "Send mode" : "Lähetystila",
    "Encryption" : "Salaus",
    "From address" : "Lähettäjän osoite",
    "mail" : "posti",
    "Authentication method" : "Tunnistautumistapa",
    "Authentication required" : "Tunnistautuminen vaaditaan",
    "Server address" : "Palvelimen osoite",
    "Port" : "Portti",
    "Credentials" : "Tilitiedot",
    "SMTP Username" : "SMTP-käyttäjätunnus",
    "SMTP Password" : "SMTP-salasana",
    "Save" : "Tallenna",
    "Test email settings" : "Testaa sähköpostiasetukset",
    "Send email" : "Lähetä sähköpostiviesti",
    "Security & setup warnings" : "Turvallisuus- ja asetusvaroitukset",
    "All checks passed." : "Läpäistiin kaikki tarkistukset.",
    "There are some errors regarding your setup." : "Asetuksiin liittyen on muutamia virheitä.",
    "There are some warnings regarding your setup." : "Asetuksiin liittyen on muutamia varoituksia.",
    "Checking for system and security issues." : "Tarkistetaan mahdollisia järjestelmä- ja tietoturvaongelmia.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Lue tarkkaan <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">asennusohjeet ↗</a>, ja tarkista virheet sekä varoitukset <a href=\"%2$s\">lokista</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Tarkista Nextcloudisi turvallisuus käyttäen <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">tietoturvakartoitustamme ↗</a>.",
    "Version" : "Versio",
    "Two-Factor Authentication" : "Kaksivaiheinen tunnistautuminen",
    "Server-side encryption" : "Palvelinpään salaus",
    "Enable server-side encryption" : "Käytä palvelinpään salausta",
    "Please read carefully before activating server-side encryption: " : "Lue tarkasti, ennen kuin otat palvelinpään salauksen käyttöön:",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Salaus sellaisenaan ei takaa järjestelmäsi turvallisuutta. Tutustu dokumentaation saadaksesi lisätietoja, miten salaussovellus toimii ja nähdäksesi tuettuja käyttötapauksia.",
    "Be aware that encryption always increases the file size." : "Ota huomioon, että salaus kasvattaa aina tiedostojen kokoa.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Säännöllisten varmuuskopioiden ottaminen on erittäin tärkeää. Jos olet ottanut salauksen käyttöön, huolehdi salausavainten varmuuskopioinnista.",
    "This is the final warning: Do you really want to enable encryption?" : "Tämä on viimeinen varoitus: haluatko varmasti ottaa salauksen käyttöön?",
    "Enable encryption" : "Käytä salausta",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Salausmoduulia ei ole käytössä. Ota salausmoduuli käyttöön sovellusvalikosta.",
    "Select default encryption module:" : "Valitse oletuksena käytettävä salausmoduuli:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen. Ota \"Default encryption module\" käyttöön ja suorita komento 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen.",
    "Start migration" : "Käynnistä migraatio",
    "Background jobs" : "Taustatyöt",
    "Last job ran %s." : "Viimeisin työ suoritettu %s.",
    "Last job execution ran %s. Something seems wrong." : "Viimeisin cron-työn suoritus %s. Jokin vaikuttaa menneen pieleen.",
    "Background job didn’t run yet!" : "Taustatyötä ei suoritettu vielä!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Optimaalisen suorituskyvyn vuoksi on tärkeää määrittää taustatyöt oikein. Suuria asennuksia varten 'Cron' on suositeltava asetus. Lisätietoja on saatavilla dokumentaatiossa.",
    "Execute one task with each page loaded" : "Suorita yksi tehtävä jokaista ladattua sivua kohden",
    "The cron.php needs to be executed by the system user \"%s\"." : "Tiedosto cron.php tulee suorittaa järjestelmän käyttäjänä \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Tämän suorittamiseksi tarvitset PHP:n POSIX-laajennuksen. Lue {linkstart}PHP:n dokumentaatio{linkend} saadaksesi lisätietoja.",
    "Sharing" : "Jakaminen",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ylläpitäjänä voit hienosäätää jakamista. Katso dokumentaatiosta lisätietoa.",
    "Allow apps to use the Share API" : "Salli sovellusten käyttää jakamisen ohjelmointirajapintaa",
    "Allow users to share via link" : "Salli käyttäjien jakaa linkkien kautta",
    "Allow public uploads" : "Salli julkiset lähetykset",
    "Always ask for a password" : "Kysy aina salasanaa",
    "Enforce password protection" : "Pakota salasanasuojaus",
    "Set default expiration date" : "Aseta oletusvanhenemispäivä",
    "Expire after " : "Vanhenna",
    "days" : "päivän jälkeen",
    "Enforce expiration date" : "Pakota vanhenemispäivä",
    "Allow resharing" : "Salli uudelleenjakaminen",
    "Allow sharing with groups" : "Salli jakaminen ryhmien kanssa",
    "Restrict users to only share with users in their groups" : "Salli käyttäjien jakaa vain omassa ryhmässä olevien henkilöiden kesken",
    "Exclude groups from sharing" : "Kiellä ryhmiä jakamasta",
    "These groups will still be able to receive shares, but not to initiate them." : "Nämä ryhmät kykenevät vastaanottamaan jakoja, mutta eivät kuitenkaan itse pysty luoda jakoja.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Salli käyttäjätunnusten automaattinen täydentäminen jakoikkunassa. Jos tämä asetus on pois käytöstä, tulee käyttäjän kirjoittaa käyttäjätunnus tai sähköpostiosoite kokonaan.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Näytä vastuuvapauslauseke julkisen linkin lähetyssivulla. (Näytetään vain, kun tiedostolista on piilotettu.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Tämä teksti näytetään julkisen linkin lähetyssivulla, kun tiedostolista on piilotettu.",
    "Default share permissions" : "Oletusjako-oikeudet",
    "Personal" : "Henkilökohtainen",
    "Administration" : "Ylläpito",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Kehityksestä on vastannut {communityopen}Nextcloud-yhteisö{linkclose}, {githubopen}lähdekoodi{linkclose} on {licenseopen}AGPL-lisensoitu{linkclose}.",
    "Like our Facebook page" : "Tykkää Facebook-sivustamme",
    "Follow us on Twitter" : "Seuraa meitä Twitterissä",
    "Follow us on Mastodon" : "Seuraa meitä Mastodonissa",
    "Check out our blog" : "Lue blogia",
    "Subscribe to our newsletter" : "Tilaa uutiskirje",
    "Profile picture" : "Profiilikuva",
    "Upload new" : "Lähetä uusi",
    "Select from Files" : "Valitse tiedostosovelluksesta",
    "Remove image" : "Poista kuva",
    "png or jpg, max. 20 MB" : "png tai jpg, korkeintaan 20 Mt",
    "Picture provided by original account" : "Kuvan tarjoaa alkuperäinen tili",
    "Cancel" : "Peru",
    "Choose as profile picture" : "Valitse profiilikuvaksi",
    "Details" : "Yksityiskohdat",
    "You are a member of the following groups:" : "Olet seuraavien ryhmien jäsen:",
    "You are using <strong>%s</strong>" : "Käytössäsi on <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Käytössäsi on <strong>%1$s</strong> / <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "Koko nimi",
    "No display name set" : "Näyttönimeä ei ole asetettu",
    "Your email address" : "Sähköpostiosoitteesi",
    "No email address set" : "Sähköpostiosoitetta ei ole asetettu",
    "For password reset and notifications" : "Salasanan nollausta ja ilmoituksia varten",
    "Phone number" : "Puhelinnumero",
    "Your phone number" : "Puhelinnumerosi",
    "Address" : "Osoite",
    "Your postal address" : "Postiosoitteesi",
    "Website" : "Verkkosivusto",
    "It can take up to 24 hours before the account is displayed as verified." : "Saattaa kestää jopa 24 tuntia, ennen kuin tili näytetään vahvistettuna.",
    "Link https://…" : "Linkki https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter-tunnus @…",
    "Help translate" : "Auta kääntämisessä",
    "Locale" : "Aluekohtainen asetus",
    "Current password" : "Nykyinen salasana",
    "Change password" : "Vaihda salasana",
    "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
    "Disconnect" : "Katkaise yhteys",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "Error while loading browser sessions and device tokens" : "Virhe ladatessa selainistuntoja ja laitepoletteja",
    "Store credentials" : "Säilytä tilitiedot",
    "Use system cron service to call the cron.php file every 15 minutes." : "Käytä järjestelmän cron-palvelua kutsuaksesi cron.php-tiedostoa 15 minuutin välein.",
    "Follow us on Google+" : "Seuraa meitä Google+:ssa"
},
"nplurals=2; plural=(n != 1);");
